Skip to contents

Identify the most abundant major lineage and sublineage.

Usage

SpaCET.calculate.mostAbundantCellType(SpaCET_obj)

Arguments

SpaCET_obj

A SpaCET object containing cell-type deconvolution results.

Value

A SpaCET object.

Details

The function compares the estimated fractions in SpaCET_obj@results$deconvolution$propMat. Candidate cell types are obtained from SpaCET_obj@results$deconvolution$Ref$lineageTree. The Unidentifiable component is not treated as a cell type. If two cell types have the same fraction, the first one in the reference lineage tree is selected.

Examples

if (FALSE) { # \dontrun{
SpaCET_obj <- SpaCET.calculate.mostAbundantCellType(SpaCET_obj)
} # }