Deconvolve malignant fraction with customized scRNAseq data
Source:R/extensions.R
SpaCET.deconvolution.malignant.customized.scRNAseq.RdExplore different malignant cell states in tumor ST dataset.
Usage
SpaCET.deconvolution.malignant.customized.scRNAseq(
SpaCET_obj,
Malignant = "Malignant",
sc_counts,
sc_annotation,
sc_lineageTree,
sc_nCellEachLineage = 100,
coreNo = 6
)Arguments
- SpaCET_obj
A SpaCET object.
- Malignant
Indicates the name of malignant cell type in the major lineage layer from the deconvolution results. Default: "Malignant".
- sc_counts
Single cell count matrix with gene name (row) x cell ID (column).
- sc_annotation
Single cell annotation matrix. This matrix should include two columns, i,e., cellID and cellType. Each row represents a single cell.
- sc_lineageTree
Cell lineage tree. This should be organized by using a list, and the name of each element are major lineages while the value of elements are the corresponding sublineages. If a major lineage does not have any sublineages, the value of this major lineage should be itself.
- sc_nCellEachLineage
Cell count each lineage. Default: 100. If a cell type is comprised of >100 cells, only 100 cells per cell identity are randomly selected to generate cell type reference.
- coreNo
Core number in parallel.