Read an ST dataset to create a SpaCET object.
Usage
create.SpaCET.object(
counts,
spotCoordinates,
metaData = NULL,
imagePath = NA,
platform,
organism = "human"
)Arguments
- counts
Count matrix with gene name (row) x spot ID (column).
- spotCoordinates
Spot coordinate matrix with spot ID (row) x coordinates (column). This matrix should include two columns, i,e., X and Y coordinates, respectively, which represent the position of spots in H&E image.
- imagePath
Path to the H&E image file. Can be NA if it is not available.
- platform
A character string indicating the platform, i.e., "Visium", "OldST", or "Slide-Seq". "OldST" is the early in situ capturing method from which "Visium" was developed.
- organism
Organism of the sample, e.g., human or mouse.