Calculate the most abundant cell type
Source:R/extensions.R
SpaCET.calculate.mostAbundantCellType.RdIdentify the most abundant major lineage and sublineage.
Details
The function compares the estimated fractions in
SpaCET_obj@results$deconvolution$propMat. Candidate cell types are
obtained from SpaCET_obj@results$deconvolution$Ref$lineageTree.
The Unidentifiable component is not treated as a cell type. If two
cell types have the same fraction, the first one in the reference lineage
tree is selected.